formattools.get_spanner_format_contributions
============================================

.. autofunction:: abjad.tools.formattools.get_spanner_format_contributions.get_spanner_format_contributions
   :noindex:
